%1-30-2008 Raj Chetty
%This file calculates effect of government loans on welfare to draw Figure 7

%psi(s) = theta*[s^(1+sigma)]/(1+sigma)
%psi'(s)=theta*s^sigma
%u(c) = [c^(1-gamma)]/(1-gamma)
%v(c) = [c^(1-gamma)]/(1-gamma)
%delta=0, r=0

clear all

w=340
T=500
a=0;
A0=100

theta = 5
sigma = 0.1
gamma = 1.75

B=26

rr_inc = .03
rr_inc_der = .02
reprate = 0.5
b=reprate*w;

toler=0.01
gridsize = 600
tau_init=0.0168*reprate(1)*w

%Private loan is L, government loan is G
L=-1000
G=0:-400:-10000

%Specify duration of loan -- need to run once with G_T=104 and once with G_T=500 to generate Figure 7
G_T = 104 

L_inc_der = 10
b_inc_der = 5

unconst_flag = 0;

tic

%1 Loan vs. UI benefit welfare calculation

for i = 1:length(A0) 
    for j = 1:length(G)
    disp(['Exact Calc.: Current loan amt ' num2str(G(j))])
   
    if unconst_flag == 0
        [D_star, D_comp_star, S_0_star, J_0_star, tau_bb, unconst_flag] = budget_balance(A0(i),L,G(j),G_T,w,a,b,tau_init,T,B,gridsize,toler,theta,sigma,gamma);
        D(j,i) = D_star;
        s_0(j,i) = S_0_star;
        J_0(j,i) = J_0_star;
        tax_pct(j,i)=tau_bb/w;
        tau_init=tau_bb;

        %calculate dJ0/dG
        [D_Linc, D_comp_Linc, S_0_Linc, J_0_Linc, tau_Linc] = budget_balance(A0(i),L,G(j)-L_inc_der,G_T,w,a,b,tau_init,T,B,gridsize,toler,theta,sigma,gamma);
        dJ_dG(j,i) = B*(J_0_Linc-J_0_star)/(L_inc_der);
    else
        dJ_dG(j,i)=0;
    end
    if unconst_flag == 0|j==1            
        %calculate dJ0/db
        [D_binc, D_comp_binc, S_0_binc, J_0_binc, tau_binc] = budget_balance(A0(i),L,G(j),G_T,w,a,b+b_inc_der,tau_init,T,B,gridsize,toler,theta,sigma,gamma);
        dJ_db(j,i) = (J_0_binc-J_0_star)/(b_inc_der);    
        %calculate dJ0/dw
        [D_winc, D_comp_winc, S_0_winc, J_0_winc, tau_winc] = budget_balance(A0(i),L,G(j),G_T,w+b_inc_der,a,b,tau_init,T,B,gridsize,toler,theta,sigma,gamma);
        dJ_dw(j,i) = (J_0_winc-J_0_star)/(b_inc_der);
    else
        dJ_db(j,i)=dJ_db(j-1,i)
        dJ_dw(j,i)=dJ_dw(j-1,i)
    end
    dG_dw = dJ_dG./dJ_dw
    db_dw = dJ_db./dJ_dw
end    
end

dG_db = dJ_dG./dJ_db

toc

%2 Construct Data

save fig7_GT104_final G d*
%save fig7_GT500_final G d*